.daiquiri-query-jobs-phases {
    label {
        margin-left: 10px;
        font-weight: normal;

        input[type=checkbox] {
            margin: 0 0 2px 0;
            vertical-align: middle;
        }
    }
}