{% load i18n %}

<button type="button" class="btn btn-default"
    ng-click="service.forms.sql.toggle_dropdown('columns')"
    ng-class="{'active': service.forms.sql.dropdown == 'columns'}">

    {% trans 'Columns' %} <span class="caret"></span>
</button>

<div class="daiquiri-query-dropdown daiquiri-query-dropdown-filter" ng-show="service.forms.sql.dropdown == 'columns'">
    <div daiquiri-browser data-browser-id="columns"></div>
    <p class="help-block small">
        {% trans 'A double click will paste the column into the query field.' %}
    </p>
</div>
