{% load i18n %}

<div ng-show="service.downloads.archive.columns.length">
    <h4>{% trans 'Download files' %}</h4>

    <ul class="list-unstyled">
        <li ng-repeat="column_name in service.downloads.archive.columns">
            <a href="" ng-click="service.downloads.start_download('archive', {column_name: column_name})">
            {% blocktrans with '{$ column_name $}' as column_name trimmed %}
                Download all files in the column "{{ column_name }}" as a zip archive
            {% endblocktrans %}
            </a>
        </li>
    </ul>
</div>
