{% load i18n %}
{% load core_tags %}

    <a href="" class="fa fa-eye" title="{% trans 'Show user details' %}"
        ng-click="service.modal('show-user-modal', $index)">
    </a>
    <a href="" class="fa fa-pencil" title="{% trans 'Update user' %}"
        ng-click="service.modal('update-user-modal', $index)">
    </a>

    <span ng-show="{$ row.id $} != {{ request.user.id }} && !row.is_pending">
        <a href="" class="fa fa-times-circle"
            ng-show="row.user.is_active" title="{% trans 'Disable user' %}"
            ng-click="service.modal('disable-user-modal', $index)">
        </a>
        <a href="" class="fa fa-check-circle"
            ng-show="!row.user.is_active" title="{% trans 'Enable user' %}"
            ng-click="service.modal('enable-user-modal', $index)">
        </a>
    </span>

    {% if settings.AUTH_WORKFLOW == 'confirmation' %}
    <span ng-show="row.is_pending && !row.is_confirmed">
        <a href="" class="fa fa-thumbs-up" title="{% trans 'Confirm the user' %}"
            ng-click="service.modal('confirm-user-modal', $index)">
        </a>
        <a href="" class="fa fa-thumbs-down" title="{% trans 'Reject the user' %}"
            ng-click="service.modal('reject-user-modal', $index)">
        </a>
    </span>
    {% elif settings.AUTH_WORKFLOW == 'activation' %}
    <span ng-show="row.is_pending">
        <a href="" class="fa fa-check" title="{% trans 'Activate the user' %}"
            ng-click="service.modal('activate-user-modal', $index)">
        </a>
        <a href="" class="fa fa-times" title="{% trans 'Reject the user' %}"
            ng-click="service.modal('reject-user-modal', $index)">
        </a>
    </span>
    {% endif %}

    {% if user.is_staff %}
    {% if settings.AUTH_WORKFLOW == 'confirmation' %}
    <a href="" class="fa fa-check" ng-show="row.is_pending && row.is_confirmed"
        ng-click="service.modal('activate-user-modal', $index)"></a>
    {% endif %}
    <a href="{{ user_admin_url }}" class="fa fa-user" title="{% trans 'User Admin' %}"></a>
    <a href="{{ profile_admin_url }}" class="fa fa-user-circle-o" title="{% trans 'Profile Admin' %}"></a>
    {% endif %}
