{% load i18n %}

<div class="modal" id="update-job-modal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">
                    <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title">
                    {% trans 'Update job' %}
                </h4>
            </div>

            <div class="modal-body">
                <formgroup
                    data-id="table_name"
                    data-type="text"
                    data-label="{% trans 'Table name' %}"
                    data-model="service.values.table_name"
                    data-errors="service.errors.table_name">
                </formgroup>
                <formgroup
                    data-id="run_id"
                    data-type="text"
                    data-label="{% trans 'Run id' %}"
                    data-model="service.values.run_id"
                    data-errors="service.errors.run_id">
                </formgroup>
            </div>

            <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">
                    {% trans 'Close' %}
                </button>
                <button type="button" class="btn btn-primary"
                        ng-click="service.update_job()">
                    {% trans 'Save' %}
                </button>
            </div>
        </div>
    </div>
</div>
