{% extends 'core/base.html' %}

{% block content %}

<main class="container">
    <div class="row">
        <section class="page col-md-9">
            {% block page %}{% endblock %}
        </section>
        <aside class="sidebar col-md-3">
            {% block sidebar %}{% endblock %}
        </aside>
    </div>
</main>

{% endblock %}
