<div class="daiquiri-table-header">
    <div class="row">
        <div class="col-sm-6">
            {% include 'core/partials/table_search.html' %}
        </div>
        <div class="col-sm-6">
            <div class="pull-right">
                {% include 'core/partials/table_pagination.html' %}
            </div>
        </div>
    </div>
</div>
