@import 'core/css/variables';

.daiquiri-browser {
    margin-bottom: 20px;
    white-space: nowrap;
}

.daiquiri-browser-head {
    border-right: 1px solid $border-color;
    border-bottom: 1px solid $border-color;
    border-left: 1px solid $border-color;
}

.daiquiri-browser-head:first-child {
    border-top: 1px solid $border-color;
}

.daiquiri-browser-body {
    height: 100px;

    overflow-x: hidden;
    overflow-y: auto;
    border-bottom: 1px solid $border-color;
    border-left: 1px solid $border-color;
    border-right: 1px solid $border-color;
}

@media (max-width: $screen-xs-max) {
    .daiquiri-browser-body {
        margin-bottom: 5px;
    }
}

@media (min-width: $screen-xs-max) {

    .daiquiri-browser .col-sm-4:nth-child(1),
    .daiquiri-browser .col-sm-4:nth-child(2) {
        padding-right: 0;
    }
    .daiquiri-browser .col-sm-4:nth-child(2),
    .daiquiri-browser .col-sm-4:nth-child(3) {
        padding-left: 0;
    }

    .daiquiri-browser .col-sm-4:nth-child(2) .daiquiri-browser-head,
    .daiquiri-browser .col-sm-4:nth-child(2) .daiquiri-browser-body,
    .daiquiri-browser .col-sm-4:nth-child(3) .daiquiri-browser-head,
    .daiquiri-browser .col-sm-4:nth-child(3) .daiquiri-browser-body {
        border-left: none;
    }
}

.daiquiri-browser .nav > li > a {
    padding: 5px 5px 5px 15px;

    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
}

.daiquiri-browser .nav-pills > li > a {
    border-radius: 0;

    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
}

.daiquiri-browser .nav-pills > li.active > a {
    color: $panel-active-color;
    background-color: $panel-active-background-color;
}

.daiquiri-browser .nav-header {
    padding: 5px 15px;
}

.daiquiri-browser i.fa {
    padding-top: 4px;
}

.tooltip-inner {
    max-width: 250px !important;
    text-align: left;
}
