<!DOCTYPE html>
<html {% block htmlargs %}{% endblock %}>

<head>

{% include 'core/base_head.html' %}
{% block headextra %}{% endblock %}

</head>

<body {% block bodyargs %}{% endblock %}>

{% include 'core/base_navigation.html' %}

{% block content %}{% endblock %}

{% include 'core/base_footer.html' %}

{% if not debug %}{% include 'core/base_analytics.html' %}{% endif %}
</body>

</html>
