{% load i18n %}
<div class="form-group form-horizontal form-inline row" align="left">
  <label class="control-label" style="width:70px"
        for="plot_x">
    {% trans 'X axis'%}
  </label>
  <select id="plot_x" 
        class="form-control select-value-md" 
        ng-model="service.plot.values.x" 
        ng-change="service.plot.errors.x = null">
    <option value="{$ option.name $}"
          ng-repeat="option in service.plot.columns">
      {$ option.name $}
    </option>
  </select>
</div>

<div class="form-group form-horizontal form-inline row">
  <label class="control-label" style="width:70px"
        for="plot_y">
    {% trans 'Y axis'%}
  </label>
  <select id="plot_y" 
        class="form-control select-value-md" 
        ng-model="service.plot.values.y" 
        ng-change="service.plot.errors.y = null">
    <option value="{$ option.name $}"
          ng-repeat="option in service.plot.columns">
      {$ option.name $}
    </option>
  </select>
</div>


<div class="form-group form-horizontal form-inline row">
  <label class="control-label" style="width:70px"
        for="plot_y2">
    {% trans 'Z axis'%}
  </label>
  <select id="plot_y2" 
        class="form-control select-value-md" 
        ng-model="service.plot.values.y2" 
        ng-change="service.plot.errors.y2 = null" 
        ng-init="">
    <option value="{$ option.name $}" 
          ng-repeat="option in service.plot.columns">
      {$ option.name $}
    </option>
  </select>
  &nbsp;
  <label class="control-label" 
        for="plot_cmap">
    {% trans 'Colormap'%}
  </label>
  <select id="plot_cmap" 
        class="form-control" 
        ng-model="service.plot.cmap">
    <option value="{$ cmapname $}" 
          ng-repeat="(cmapname, cmapdata) in service.plot.available_cmaps">
      {$ cmapname $}
    </option>
  </select>
</div>

