@import 'core/css/variables';

.daiquiri-list {
    .daiquiri-list-header {
        margin-top: 20px;
        margin-bottom: 10px;

        form,
        .pagination {
            margin-top: 0;
            margin-bottom: 10px;
        }
        .count {
            display: inline-block;
            padding: 7px 0;
        }
        .pagination {
            margin-left: 5px;
        }

        @media (max-width: $screen-md-max) {
            .pull-right {
                float: none!important;
            }
        }
    }
    .daiquiri-list-table {
        th .order {
            cursor: pointer;

            i {
                opacity: 0.2;
            }
            i.ordered {
                opacity: 1;
            }
        }
        ul {
            margin-bottom: 0;
        }
        .options {
            a.fa {
                width: 16px;
                text-align: center;
            }
            .dropdown {
                display: inline-block;

                a.dropdown-toggle {
                    cursor: pointer;
                }
            }
        }
    }
    .daiquiri-list-filter {
        label {
            margin-left: 10px;
            font-weight: normal;

            input[type=checkbox] {
                margin: 0 0 2px 0;
                vertical-align: middle;
            }
        }
    }
}
