@import 'core/css/variables';

.daiquiri-metadata-browser .daiquiri-browser-body {
    height: 400px;
}

.daiquiri-metadata-display {

    margin-bottom: 20px;

    dl,
    ul {
        margin-bottom: 0;
    }

    .dl-horizontal {
        dt {
            text-align: left;
            font-weight: normal;
        }
        dd {
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
        }
    }

    .daiquiri-metadata-display-title {
        height: 20px;
        margin-bottom: 10px;
    }
}

.daiquiri-metadata-modal-person {
    border-bottom: 1px solid $modal-border-color;
    margin-bottom: 15px;
}

.CodeMirror {
    height: 600px;
}
