{% load i18n %}

{% for download in settings.QUERY_DOWNLOADS %}
{% include download.template %}
{% endfor %}

<p class="text-info" ng-show="service.downloads.pending_downloads">
    <i class="fa fa-cog fa-spin fa-fw"></i> {% trans 'Your file is being created. Please wait...' %}
</p>
<p class="text-danger" ng-show="service.job.download_failed">
    {% trans 'The download file could not be created.' %}
</p>
