{% load i18n %}

<p>
    {% trans 'For further processing of the data, you can download the results table to your local machine. For this file several formats are available. Please choose a format for the download from the list below.' %}
</p>

<div>
    <h4>{% trans 'Download table' %}</h4>

    {% for download_format in settings.QUERY_DOWNLOAD_FORMATS %}
    <div class="row">
        <div class="col-md-3">
            <p>
                <a href="" ng-click="service.downloads.start_download('table', {format_key: '{{ download_format.key }}'})">
                    {{ download_format.label }}
            </a>
            </p>
        </div>
        <div class="col-md-9">
            <p>
                {{ download_format.help }}
            </p>
        </div>
    </div>
    {% endfor %}
</div>
