{% load i18n %}
{% load core_tags %}

    <a href="" class="fa fa-pencil" title="{% trans 'Update example details' %}"
        ng-click="service.modal('examples-modal-form', $index)">
    </a>
    <a href="" class="fa fa-trash"
        title="{% trans 'Delete example' %}"
        ng-click="service.modal('examples-modal-delete', $index)">
    </a>
