{% load i18n %}

<div class="form-group form-inline form-horizontal row" align="left">
  <label class="control-label" style="width:70px" align="left"
        for="plot_x">
    {% trans 'Column'%}
  </label>
  <select id="plot_x" 
        class="form-control select-value-md" 
        ng-model="service.plot.values.x" 
        ng-change="service.plot.errors.x = null">
    <option value="{$ option.name $}"
          ng-repeat="option in service.plot.columns">
      {$ option.name $}
    </option>
  </select>
</div>

<div class="form-group form-inline form-horizontal row" align="left">
  <label class="control-label" style="width:70px" align="left"
        for="plot_filter">
    {% trans 'Select'%}
  </label>
  <select id="plot_filter" 
        class="form-control select-value-md" 
        ng-model="service.plot.values.y2" 
        ng-change="service.plot.errors.y2 = null">
    <option value="">---</option>
    <option value="{$ option.name $}" 
          ng-repeat="option in service.plot.columns">
      {$ option.name $}
    </option>
  </select>

  <select class="form-control"
        ng-model="service.plot.values.hist_op" 
        id="plot_filter_op">
    <option value="{$ op $}"
          ng-repeat="op in service.plot.available_hist_op">
      {$ op $}
    </option>
  </select>

  <input class="form-control select-value-sm" 
      size="1" 
      type="number" 
      id="plot_filter_number" 
      ng-model="service.plot.values.hist_filter_number"/>
</div>
