{% load i18n %}

    <div class="modal" id="show-message-modal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">

                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="{% trans 'Close' %}">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h4 class="modal-title">
                        {% trans 'Contact message' %}
                    </h4>
                </div>

                <div class="modal-body">
                    <dl>
                        <dt>{% trans 'Author' %}</dt>
                        <dd>{$ service.current_row.author $}</dd>
                    </dl>
                    <dl>
                        <dt>{% trans 'Email' %}</dt>
                        <dd>{$ service.current_row.email $}</dd>
                    </dl>
                    <dl>
                        <dt>{% trans 'Created' %}</dt>
                        <dd>{$ service.current_row.created | date: 'MMM d, yyyy hh:mm'  $}</dd>
                    </dl>
                    <dl>
                        <dt>{% trans 'Status' %}</dt>
                        <dd>{$ service.current_row.status_label $}</dd>
                    </dl>
                    <div class="modal-seperator"></div>
                    <dl>
                        <dt>{% trans 'Subject' %}</dt>
                        <dd>{$ service.current_row.subject $}</dd>

                    <dl>
                        <dt>{% trans 'Message' %}</dt>
                        <dd>{$ service.current_row.message $}</dd>
                    </dl>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">
                        {% trans 'Close' %}
                    </button>
                </div>
            </div>
        </div>
    </div>
