{% for schema in schemas %}
<li>
    <a href="{% url 'metadata:schema' schema.name %}">{{ schema.label }}</a>

    <ul class="sub-menu">
        {% for table in schema.tables %}
        <li>
            <a href="{% url 'metadata:table' schema.name table.name %}">{{ table.label }}</a>
        </li>
        {% endfor %}
    </ul>
</li>
{% endfor %}
