{% load i18n %}

<button type="button" class="btn btn-default pull-right"
    ng-click="service.forms.sql.toggle_dropdown('examples')"
    ng-class="{'active': service.forms.sql.dropdown == 'examples'}">

    {% trans 'Examples' %} <span class="caret"></span>
</button>

<div class="daiquiri-query-dropdown" ng-show="service.forms.sql.dropdown == 'examples'">
    <div daiquiri-browser data-browser-id="examples" class="daiquiri-metadata-browser"></div>
    <p class="help-block small">
        {% trans 'A double click will replace the content of the query field with the example.' %}
    </p>
</div>
