/* responsive thresholds */

$screen-xs-max: 768px;
$screen-sm-max: 992px;
$screen-md-max: 1200px;

/* main */

$text-color: #000000;
$variant-color: #999999;
$background-color: transparent;

$headline-color: #333333;
$headline-background-color: transparent;

$link-color: #337ab7;
$link-color-hover: #23527c;
$link-color-visited: $link-color;
$link-color-focus: $link-color;

/* navigation */

$navigation-color: #9d9d9d;
$navigation-background-color: #000;
$navigation-hover-color: #fff;
$navigation-hover-background-color: rgba(255, 255, 255, 0.2);
$navigation-dropdown-color: #333;
$navigation-dropdown-hover-color: #262626;
$navigation-dropdown-hover-background-color: #f5f5f5;

/* footer */

$footer-content-height: 250px;
$footer-bottom-height: 50px;

$footer-content-color: #fff;
$footer-content-background-color: #444B53;
$footer-content-link-color: #ccc;
$footer-content-link-color-hover: $footer-content-link-color;
$footer-content-link-color-visited: $footer-content-link-color;
$footer-content-link-color-focus: $footer-content-link-color;

$footer-bottom-color: #fff;
$footer-bottom-background-color: #000;
$footer-bottom-link-color: #ccc;
$footer-bottom-link-color-hover: $footer-bottom-link-color;
$footer-bottom-link-color-visited: $footer-bottom-link-color;
$footer-bottom-link-color-focus: $footer-bottom-link-color;

/* panels */

$panel-hover-color: #23527c;
$panel-hover-background-color: #eee;
$panel-active-color: #fff;
$panel-active-background-color: #08c;

/* misc */

$border-color: #CCCCCC;

$table-active-background-color: #efefef;

$error-color: #a94442;
$error-background-color: rgba(169, 68, 68, 0.3);

$modal-border-color: #e5e5e5;
