{% include 'core/partials/table_tooltip.html' %}

<div class="daiquiri-table" ng-show="service.table.ready">

    {% include 'core/partials/table_header.html' %}

    {% include 'core/partials/table_pane.html' %}

    {% include 'core/partials/table_footer.html' %}

</div>

{% include 'core/partials/table_modal.html' %}
