{% load i18n %}

<div class="panel panel-default panel-doi">
    <div class="panel-heading">{% trans 'Digital object identifier' %}</div>
    <div class="panel-body">
        <p>
            {% blocktrans %}
            You can use the following <a href="https://www.doi.org" target="_blank">DOI</a> to cite this {{ dataset }} in a publication:
            {% endblocktrans %}
        </p>
        <p>
            <a class="break" href="{{ doi_url }}">{{ doi_url }}</a>
        </p>
    </div>
</div>
