{% load i18n %}

<div class="modal" id="logout-modal" tabindex="-1" data-backdrop="static" data-keyboard="false">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">
                    {% trans 'Logout' %}
                </h4>
            </div>

            <div class="modal-body">
                <p>
                    {% blocktrans trimmed with table_name='{$ service.values.table_name $}' %}
                    You have been logged out. This happens after a certain time or when you have logged out in another window.
                    {% endblocktrans %}
                </p>
            </div>

            <div class="modal-footer">
                <a type="button" href="{% url 'query:query' %}" class="btn btn-default">
                    {% trans 'Continue as guest' %}
                </a>
                <a type="button" href="{% url 'account_login' %}?next={% url 'query:query' %}" class="btn btn-primary">
                    {% trans 'Login' %}
                </a>
            </div>
        </div>
    </div>
</div>
