__title__ = 'django-daiquiri'
__version__ = '0.4.5'
__author__ = 'Jochen Klar'
__email__ = 'mail@jochenklar.de'
__license__ = 'Apache-2.0'
__copyright__ = 'Copyright 2016-2023 Leibniz Institute for Astrophysics Potsdam (AIP)'

VERSION = __version__
