{% load i18n %}

<form class="daiquiri-table-search" ng-submit="service.table.search()">
    <div class="input-group">
        <input type="search" class="form-control" placeholder="{% trans 'Search' %}" ng-model="service.table.search_string">
        <span class="input-group-btn">
            <button class="btn btn-default" type="submit">
                <i class="fa fa-search" aria-hidden="true"></i>
            </button>
        </span>
    </div>
</form>
