{% load i18n %}

<div class="modal" id="archive-job-modal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">
                    <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title">
                    {% trans 'Archive job' %}
                </h4>
            </div>

            <div class="modal-body">
                <p>
                    {% blocktrans trimmed with table_name='{$ service.values.table_name $}' %}
                    You are about to archive the job <code>{{ table_name }}</code>.
                    {% endblocktrans %}
                </p>
                <p class="text-danger">
                    {% trans 'This action cannot be undone!' %}
                </p>
            </div>

            <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">
                    {% trans 'Close' %}
                </button>
                <button type="button" class="btn btn-danger"
                        ng-click="service.archive_job()">
                    {% trans 'Archive' %}
                </button>
            </div>
        </div>
    </div>
</div>
