{% load i18n %}

    <div class="modal" id="schemas-contributors-form-modal" tabindex="-1">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" tabindex="-1">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h4 class="modal-title">
                        {% trans 'Update schema contributors' %}
                    </h4>
                </div>

                <div class="modal-body">
                    <div class="daiquiri-metadata-modal-person"
                        ng-repeat="contributor in service.values.contributors">

                        <div class="row">
                            <formgroup
                                class="col-md-4"
                                data-type="text"
                                data-label="{% trans 'Name' %}"
                                data-model="contributor.name">
                            </formgroup>
                            <formgroup
                                class="col-md-4"
                                data-type="text"
                                data-label="{% trans 'First name' %}"
                                data-model="contributor.first_name">
                            </formgroup>
                            <formgroup
                                class="col-md-4"
                                data-type="text"
                                data-label="{% trans 'Last name' %}"
                                data-model="contributor.last_name">
                            </formgroup>
                        </div>
                        <div class="row">
                            <formgroup
                                class="col-md-4"
                                data-type="text"
                                data-label="{% trans 'ORCID' %}"
                                data-model="contributor.orcid">
                            </formgroup>
                            <div class="col-md-4">
                            </div>
                            <div class="col-md-4">
                                <button type="button" class="btn btn-danger form-inline-button"
                                    ng-click="service.removePerson('contributors', $index)">

                                    {% trans 'Remove contributor' %}
                                </button>
                            </div>
                        </div>
                    </div>

                    <button type="button" class="btn btn-success" ng-click="service.addPerson('contributors')">
                        {% trans 'Add contributor' %}
                    </button>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">
                        {% trans 'Close' %}
                    </button>
                    <button type="button" class="btn btn-primary"
                            ng-click="service.submitFormModal('schemas')">
                        {% trans 'Save' %}
                    </button>
                </div>
            </div>
        </div>
    </div>
