{% load i18n %}
{% load core_tags %}

    <a href="{% include 'contact/messages_mailto.html' %}" class="fa fa-reply"
        title="{% trans 'Reply to message' %}">
    </a>
    <a href="" class="fa fa-eye" title="{% trans 'Show message details' %}"
        ng-click="service.modal('show-message-modal', $index)">
    </a>
    <a href="" ng-show="row.status == 'ACTIVE'"
        class="fa fa-square-o" title="{% trans 'Close the thread' %} "
        ng-click="service.updateMessage(row, 'CLOSED')">
    </a>
    <a href="" ng-show="row.status == 'CLOSED'" class="fa fa-check" title="{% trans 'Open the thread' %}"
        ng-click="service.updateMessage(row, 'ACTIVE')">
    </a>
    <a href="" class="fa fa-ban" title="{% trans 'Mark as spam' %}"
        ng-hide="row.status == 'SPAM'"
        ng-click="service.updateMessage(row, 'SPAM')">
    </a>
    <a href="" class="fa fa-thumbs-o-up" title="{% trans 'Not spam' %}"
        ng-hide="row.status != 'SPAM'"
        ng-click="service.updateMessage(row, 'ACTIVE')">
    </a>
