{% load i18n %}

<div class="modal daiquiri-table-modal" id="daiquiri-table-modal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">
                    <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title">
                    {$ service.table.modal.title $}
                    {$ service.table.modal_left_column_index() $}
                </h4>
            </div>

            <div class="modal-pagination">
                <a class="modal-pagination-up" href=""
                    ng-hide="service.table.modal.up_row_index === false"
                    ng-click="service.table.modal_up()">
                    <span class="fa fa-chevron-up fa-4x"></span>
                </a>
                <a class="modal-pagination-down" href=""
                    ng-hide="service.table.modal.down_row_index === false"
                    ng-click="service.table.modal_down()">
                    <span class="fa fa-chevron-down fa-4x"></span>
                </a>
                <a class="modal-pagination-left" href=""
                    ng-hide="service.table.modal.left_row_index === false"
                    ng-click="service.table.modal_left()">
                    <span class="fa fa-chevron-left fa-4x"></span>
                </a>
                <a class="modal-pagination-right" href=""
                    ng-hide="service.table.modal.right_row_index === false"
                    ng-click="service.table.modal_right()">
                    <span class="fa fa-chevron-right fa-4x"></span>
                </a>
            </div>

            <div class="modal-body">
                <ul ng-show="service.table.modal.links">
                    <li ng-repeat="link in service.table.modal.links">
                        <a href="{$ link.href $}" target="_blank">{$ link.text $}</a>
                    </li>
                </ul>
                <pre ng-show="service.table.modal.pre">{$ service.table.modal.pre $}</pre>
                <img class="center-block" ng-show="service.table.modal.src"
                    ng-src="{$ service.table.modal.src $}" ng-attr-alt="{$ service.table.modal.title $}" />

            </div>

            <div class="modal-footer">
                <div class="pull-left">
                    <a href="{$ service.table.modal.url $}">
                        {% trans 'Download file' %}
                    </a>
                </div>
            </div>

        </div>
    </div>
</div>
